@@ -76,7 +76,7 @@ from .document import CT_Body, CT_Document  # noqa
 register_element_cls('w:body',     CT_Body)
 register_element_cls('w:document', CT_Document)
 
-from .numbering import CT_Num, CT_Numbering, CT_NumLvl, CT_NumPr  # noqa
+from .numbering import CT_Num, CT_Numbering, CT_NumLvl, CT_NumPr, CT_AbstractNum, CT_Lvl  # noqa
 register_element_cls('w:abstractNumId', CT_DecimalNumber)
 register_element_cls('w:ilvl',          CT_DecimalNumber)
 register_element_cls('w:lvlOverride',   CT_NumLvl)
@@ -85,6 +85,15 @@ register_element_cls('w:numId',         CT_DecimalNumber)
 register_element_cls('w:numPr',         CT_NumPr)
 register_element_cls('w:numbering',     CT_Numbering)
 register_element_cls('w:startOverride', CT_DecimalNumber)
+register_element_cls('w:abstractNum',   CT_AbstractNum)
+register_element_cls('w:lvl',           CT_Lvl)
+register_element_cls('w:nsid',          CT_String)
+register_element_cls('w:multiLevelType',    CT_String)
+register_element_cls('w:tmpl',          CT_String)
+register_element_cls('w:numFmt',        CT_String)
+register_element_cls('w:suff',          CT_String)
+register_element_cls('w:lvlText',       CT_String)
+register_element_cls('w:lvlJc',         CT_String)
 
 from .section import (  # noqa
     CT_HdrFtr,
@@ -93,6 +102,7 @@ from .section import (  # noqa
     CT_PageSz,
     CT_SectPr,
     CT_SectType,
+    CT_Cols,
 )
 register_element_cls("w:footerReference", CT_HdrFtrRef)
 register_element_cls("w:ftr", CT_HdrFtr)
@@ -100,6 +110,7 @@ register_element_cls("w:hdr", CT_HdrFtr)
 register_element_cls("w:headerReference", CT_HdrFtrRef)
 register_element_cls("w:pgMar", CT_PageMar)
 register_element_cls("w:pgSz", CT_PageSz)
+register_element_cls("w:cols", CT_Cols)
 register_element_cls("w:sectPr", CT_SectPr)
 register_element_cls("w:type", CT_SectType)
 
@@ -294,4 +305,4 @@ register_element_cls('v:oval', CT_Oval)
 register_element_cls('v:fill', CT_Fill)
 register_element_cls('v:roundrect', CT_Roundrect)
 register_element_cls('v:textbox', CT_Textbox)
-register_element_cls('w:txbxContent', CT_TxbxContent)
\ No newline at end of file
+register_element_cls('w:txbxContent', CT_TxbxContent)
