@@ -18,6 +18,10 @@ class TextboxContent(Parented):
         """
         return [Paragraph(p, self) for p in self._txbxContent.p_lst]
 
+    @property
+    def has_warp(self):
+        return self._txbxContent.shape.has_wrap
+
     @property
     def off_x(self):
         if isinstance(self._txbxContent.shape, GroupBaseOxmlElement):
